==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/PolicyParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters in Policy
 * @property backupDatasourceParametersList Gets or sets the Backup Data Source Parameters
 * @property dataStoreParametersList Gets or sets the DataStore Parameters
 */
public data class PolicyParametersArgs(
    public val backupDatasourceParametersList:
    Output<List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>? =
        null,
    public val dataStoreParametersList: Output<List<AzureOperationalStoreParametersArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs =
        com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs.builder()
            .backupDatasourceParametersList(
                backupDatasourceParametersList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .dataStoreParametersList(
                dataStoreParametersList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [PolicyParametersArgs].
 */
@PulumiTagMarker
public class PolicyParametersArgsBuilder internal constructor() {
    private var backupDatasourceParametersList:
        Output<List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>? =
        null

    private var dataStoreParametersList: Output<List<AzureOperationalStoreParametersArgs>>? = null

    /**
     * @param value Gets or sets the Backup Data Source Parameters
     */
    @JvmName("yrftglfdwhtubifv")
    public suspend
    fun backupDatasourceParametersList(`value`: Output<List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>) {
        this.backupDatasourceParametersList = value
    }

    @JvmName("rdpnbxqprxvxybgp")
    public suspend fun backupDatasourceParametersList(
        vararg
        values: Output<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>,
    ) {
        this.backupDatasourceParametersList = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the Backup Data Source Parameters
     */
    @JvmName("rkfqqgnrblybjeof")
    public suspend
    fun backupDatasourceParametersList(values: List<Output<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>) {
        this.backupDatasourceParametersList = Output.all(values)
    }

    /**
     * @param value Gets or sets the DataStore Parameters
     */
    @JvmName("alvlsddcenvidypc")
    public suspend
    fun dataStoreParametersList(`value`: Output<List<AzureOperationalStoreParametersArgs>>) {
        this.dataStoreParametersList = value
    }

    @JvmName("hbfyodkfmjliopao")
    public suspend fun dataStoreParametersList(
        vararg
        values: Output<AzureOperationalStoreParametersArgs>,
    ) {
        this.dataStoreParametersList = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the DataStore Parameters
     */
    @JvmName("xanokbylibnroiie")
    public suspend
    fun dataStoreParametersList(values: List<Output<AzureOperationalStoreParametersArgs>>) {
        this.dataStoreParametersList = Output.all(values)
    }

    /**
     * @param value Gets or sets the Backup Data Source Parameters
     */
    @JvmName("ejngbgjiqdjewcwe")
    public suspend
    fun backupDatasourceParametersList(`value`: List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupDatasourceParametersList = mapped
    }

    /**
     * @param values Gets or sets the Backup Data Source Parameters
     */
    @JvmName("cqampsopyfitfgcr")
    public suspend fun backupDatasourceParametersList(
        vararg
        values: Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupDatasourceParametersList = mapped
    }

    /**
     * @param value Gets or sets the DataStore Parameters
     */
    @JvmName("uxaugtpmwxphmryh")
    public suspend fun dataStoreParametersList(`value`: List<AzureOperationalStoreParametersArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataStoreParametersList = mapped
    }

    /**
     * @param argument Gets or sets the DataStore Parameters
     */
    @JvmName("evensimifrmorbfl")
    public suspend
    fun dataStoreParametersList(argument: List<suspend AzureOperationalStoreParametersArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureOperationalStoreParametersArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataStoreParametersList = mapped
    }

    /**
     * @param argument Gets or sets the DataStore Parameters
     */
    @JvmName("utwgoyvifjnakyjk")
    public suspend fun dataStoreParametersList(
        vararg
        argument: suspend AzureOperationalStoreParametersArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureOperationalStoreParametersArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataStoreParametersList = mapped
    }

    /**
     * @param argument Gets or sets the DataStore Parameters
     */
    @JvmName("fajddxfgxgjsyusx")
    public suspend
    fun dataStoreParametersList(argument: suspend AzureOperationalStoreParametersArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AzureOperationalStoreParametersArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dataStoreParametersList = mapped
    }

    /**
     * @param values Gets or sets the DataStore Parameters
     */
    @JvmName("hvybnulveyvrbvjl")
    public suspend fun dataStoreParametersList(vararg values: AzureOperationalStoreParametersArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataStoreParametersList = mapped
    }

    internal fun build(): PolicyParametersArgs = PolicyParametersArgs(
        backupDatasourceParametersList = backupDatasourceParametersList,
        dataStoreParametersList = dataStoreParametersList,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/PolicyParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters in Policy
 * @property backupDatasourceParametersList Gets or sets the Backup Data Source Parameters
 * @property dataStoreParametersList Gets or sets the DataStore Parameters
 */
public data class PolicyParametersArgs(
    public val backupDatasourceParametersList:
    Output<List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>? =
        null,
    public val dataStoreParametersList: Output<List<AzureOperationalStoreParametersArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs =
        com.pulumi.azurenative.dataprotection.inputs.PolicyParametersArgs.builder()
            .backupDatasourceParametersList(
                backupDatasourceParametersList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .dataStoreParametersList(
                dataStoreParametersList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [PolicyParametersArgs].
 */
@PulumiTagMarker
public class PolicyParametersArgsBuilder internal constructor() {
    private var backupDatasourceParametersList:
        Output<List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>? =
        null

    private var dataStoreParametersList: Output<List<AzureOperationalStoreParametersArgs>>? = null

    /**
     * @param value Gets or sets the Backup Data Source Parameters
     */
    @JvmName("oekamqpkugfqbibk")
    public suspend
    fun backupDatasourceParametersList(`value`: Output<List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>) {
        this.backupDatasourceParametersList = value
    }

    @JvmName("nonxchnjqljwkebc")
    public suspend fun backupDatasourceParametersList(
        vararg
        values: Output<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>,
    ) {
        this.backupDatasourceParametersList = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the Backup Data Source Parameters
     */
    @JvmName("wkcsamokfhwtsywf")
    public suspend
    fun backupDatasourceParametersList(values: List<Output<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>>) {
        this.backupDatasourceParametersList = Output.all(values)
    }

    /**
     * @param value Gets or sets the DataStore Parameters
     */
    @JvmName("pyilevsccturmkfo")
    public suspend
    fun dataStoreParametersList(`value`: Output<List<AzureOperationalStoreParametersArgs>>) {
        this.dataStoreParametersList = value
    }

    @JvmName("qeyatgcikpstcrnb")
    public suspend fun dataStoreParametersList(
        vararg
        values: Output<AzureOperationalStoreParametersArgs>,
    ) {
        this.dataStoreParametersList = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the DataStore Parameters
     */
    @JvmName("xrrqgjfylhecvsur")
    public suspend
    fun dataStoreParametersList(values: List<Output<AzureOperationalStoreParametersArgs>>) {
        this.dataStoreParametersList = Output.all(values)
    }

    /**
     * @param value Gets or sets the Backup Data Source Parameters
     */
    @JvmName("btecjtmsfxdbjitf")
    public suspend
    fun backupDatasourceParametersList(`value`: List<Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupDatasourceParametersList = mapped
    }

    /**
     * @param values Gets or sets the Backup Data Source Parameters
     */
    @JvmName("bcpxcbvfkeyybavt")
    public suspend fun backupDatasourceParametersList(
        vararg
        values: Either<BlobBackupDatasourceParametersArgs, KubernetesClusterBackupDatasourceParametersArgs>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupDatasourceParametersList = mapped
    }

    /**
     * @param value Gets or sets the DataStore Parameters
     */
    @JvmName("fjtvetgvfciocgrv")
    public suspend fun dataStoreParametersList(`value`: List<AzureOperationalStoreParametersArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataStoreParametersList = mapped
    }

    /**
     * @param argument Gets or sets the DataStore Parameters
     */
    @JvmName("vqmoritpeebyqlpt")
    public suspend
    fun dataStoreParametersList(argument: List<suspend AzureOperationalStoreParametersArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureOperationalStoreParametersArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataStoreParametersList = mapped
    }

    /**
     * @param argument Gets or sets the DataStore Parameters
     */
    @JvmName("ijfuungimmlfhrbc")
    public suspend fun dataStoreParametersList(
        vararg
        argument: suspend AzureOperationalStoreParametersArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureOperationalStoreParametersArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataStoreParametersList = mapped
    }

    /**
     * @param argument Gets or sets the DataStore Parameters
     */
    @JvmName("mpwaxtlwaqghvrsd")
    public suspend
    fun dataStoreParametersList(argument: suspend AzureOperationalStoreParametersArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AzureOperationalStoreParametersArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dataStoreParametersList = mapped
    }

    /**
     * @param values Gets or sets the DataStore Parameters
     */
    @JvmName("ikryshcbgesochti")
    public suspend fun dataStoreParametersList(vararg values: AzureOperationalStoreParametersArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataStoreParametersList = mapped
    }

    internal fun build(): PolicyParametersArgs = PolicyParametersArgs(
        backupDatasourceParametersList = backupDatasourceParametersList,
        dataStoreParametersList = dataStoreParametersList,
    )
}
